@@ -3,14 +3,14 @@
  *
  * Copyright (C) 2001-2004
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2003-2010
+ * Copyright (C) 2003-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  * Copyright (C) 2003
  *  Toni Andjelkovic <toni@soth.at>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: hotplug_libusb.c 5636 2011-02-24 19:34:58Z rousseau $
+ * $Id: hotplug_libusb.c 5938 2011-09-03 21:43:53Z rousseau $
  */
 
 /**
@@ -32,6 +32,7 @@
 #include <errno.h>
 #include <libusb.h>
 #include <pthread.h>
+#include <signal.h>
 
 #include "misc.h"
 #include "wintypes.h"
@@ -217,6 +218,7 @@ static LONG HPReadBundleValues(void)
 					{
 						Log1(PCSC_LOG_CRITICAL, "Not enough memory");
 						driverSize = -1;
+						closedir(hpDir);
 						return -1;
 					}
 
@@ -352,6 +354,7 @@ static void HPRescanUsbBus(void)
 				}
 			}
 		}
+		libusb_free_config_descriptor(config_desc);
 	}
 
 	/*
@@ -388,9 +391,17 @@ static void HPRescanUsbBus(void)
 static void HPEstablishUSBNotifications(int pipefd[2])
 {
 	int i, do_polling;
+	int r;
 	char c = 42;	/* magic value */
 
-	libusb_init(ctx);
+	r = libusb_init(ctx);
+	if (r < 0)
+	{
+		Log2(PCSC_LOG_CRITICAL, "libusb_init failed: %d", r);
+		/* emergency exit */
+		kill(getpid(), SIGTERM);
+		return;
+	}
 
 	/* scan the USB bus for devices at startup */
 	HPRescanUsbBus();
@@ -615,7 +626,8 @@ ULONG HPRegisterForHotplugEvents(void)
 
 void HPReCheckSerialReaders(void)
 {
-  	if (rescan_pipe[1] >= 0)
+	Log0(PCSC_LOG_INFO);
+	if (rescan_pipe[1] >= 0)
 	{
 		char dummy = 0;
 		write(rescan_pipe[1], &dummy, sizeof(dummy));
