@@ -1,10 +1,10 @@
 /*
  * MUSCLE SmartCard Development ( http://www.linuxnet.com )
  *
- * Copyright (C) 2006-2009
+ * Copyright (C) 2006-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id$
+ * $Id: pcscd.h.in 6071 2011-10-24 11:51:08Z rousseau $
  */
 
 /**
@@ -32,7 +32,7 @@
 
 #define PCSCLITE_SVC_IDENTITY		0x01030000	/**< Service ID */
 
-#define PCSCLITE_VERSION_NUMBER		"1.6.6"	/**< Current version */
+#define PCSCLITE_VERSION_NUMBER		"1.8.1"	/**< Current version */
 #define PCSCLITE_STATUS_POLL_RATE	400000		/**< Status polling rate */
 #define PCSCLITE_LOCK_POLL_RATE		100000		/**< Lock polling rate */
 
@@ -43,9 +43,6 @@
 #define PCSCLITE_STATUS_WAIT		200000	/**< Status Change Sleep */
 #define MAX_DEVICENAME		255
 
-#define MAX_BUFFER_SIZE			264	/**< Maximum Tx/Rx Buffer for get/set attributes */
-#define MAX_BUFFER_SIZE_EXTENDED	(4 + 3 + (1<<16) + 3)	/**< max APDU (64K + APDU + Lc + Le) Tx/Rx Buffer */
-
 /** Different values for struct ReaderContext powerState field */
 enum
 {
