@@ -5,12 +5,12 @@
  *  David Corcoran <corcoran@linuxnet.com>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
- * Copyright (C) 2002-2010
+ * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  * Copyright (C) 2009
  *  Jean-Luc Giraud <jlgiraud@googlemail.com>
  *
- * $Id: readerfactory.c 5415 2010-11-23 08:30:14Z rousseau $
+ * $Id: readerfactory.c 5992 2011-10-02 15:42:35Z rousseau $
  */
 
 /**
@@ -31,7 +31,6 @@
 
 #include "misc.h"
 #include "pcscd.h"
-#include "ifdhandler.h"
 #include "debuglog.h"
 #include "readerfactory.h"
 #include "dyn_generic.h"
@@ -65,9 +64,12 @@ static int RDR_CLIHANDLES_seeker(const void *el, const void *key)
 	const RDR_CLIHANDLES *rdrCliHandles = el;
 
 	if ((el == NULL) || (key == NULL))
+	{
 		Log3(PCSC_LOG_CRITICAL,
-			"RDR_CLIHANDLES_seeker called with NULL pointer: el=%X, key=%X",
+			"RDR_CLIHANDLES_seeker called with NULL pointer: el=%p, key=%p",
 			el, key);
+		return 0;
+	}
 
 	if (rdrCliHandles->hCard == *(SCARDHANDLE *)key)
 		return 1;
@@ -119,7 +121,8 @@ LONG RFAddReader(const char *readerName, int port, const char *library,
 	/* Reader name too long? also count " 00 00"*/
 	if (strlen(readerName) > MAX_READERNAME - sizeof(" 00 00"))
 	{
-		Log3(PCSC_LOG_ERROR, "Reader name too long: %d chars instead of max %d",
+		Log3(PCSC_LOG_ERROR,
+			"Reader name too long: %zd chars instead of max %zd",
 			strlen(readerName), MAX_READERNAME - sizeof(" 00 00"));
 		return SCARD_E_INVALID_VALUE;
 	}
@@ -169,7 +172,7 @@ LONG RFAddReader(const char *readerName, int port, const char *library,
 
 	/* Check and set the readername to see if it must be enumerated */
 	parentNode = RFSetReaderName(sReadersContexts[dwContext], readerName,
-		library, port, 0);
+		library, port);
 	if (parentNode < -1)
 		return SCARD_E_NO_MEMORY;
 
@@ -341,7 +344,7 @@ LONG RFAddReader(const char *readerName, int port, const char *library,
 		if (i == PCSCLITE_MAX_READERS_CONTEXTS)
 		{
 			/* No more slot left return */
-			rv = RFRemoveReader(readerName, port);
+			RFRemoveReader(readerName, port);
 			return SCARD_E_NO_MEMORY;
 		}
 
@@ -350,7 +353,7 @@ LONG RFAddReader(const char *readerName, int port, const char *library,
 		(void)strlcpy(tmpReader,
 			sReadersContexts[dwContext]->readerState->readerName,
 			sizeof(sReadersContexts[dwContextB]->readerState->readerName));
-		sprintf(tmpReader + strlen(tmpReader) - 2, "%02X", j);
+		snprintf(tmpReader + strlen(tmpReader) - 2, 3, "%02X", j);
 
 		sReadersContexts[dwContextB]->library =
 			sReadersContexts[dwContext]->library;
@@ -368,6 +371,7 @@ LONG RFAddReader(const char *readerName, int port, const char *library,
 		  sReadersContexts[dwContext]->pMutex;
 		sReadersContexts[dwContextB]->slot =
 			sReadersContexts[dwContext]->slot + j;
+		sReadersContexts[dwContextB]->pthCardEvent = NULL;
 
 		/*
 		 * Added by Dave - slots did not have a pFeeds
@@ -476,11 +480,6 @@ LONG RFRemoveReader(const char *readerName, int port)
 		if (sContext -> pthThread)
 			(void)EHDestroyEventHandler(sContext);
 
-		rv = RFUnInitializeReader(sContext);
-		if (rv != SCARD_S_SUCCESS)
-			return rv;
-
-		/* Destroy and free the mutex */
 		if ((NULL == sContext->pMutex) || (NULL == sContext->pFeeds))
 		{
 			Log1(PCSC_LOG_ERROR,
@@ -488,6 +487,10 @@ LONG RFRemoveReader(const char *readerName, int port)
 			return SCARD_E_INVALID_VALUE;
 		}
 
+		rv = RFUnInitializeReader(sContext);
+		if (rv != SCARD_S_SUCCESS)
+			return rv;
+
 		*sContext->pMutex -= 1;
 
 		/* free shared resources when the last slot is closed */
@@ -546,7 +549,7 @@ LONG RFRemoveReader(const char *readerName, int port)
 }
 
 LONG RFSetReaderName(READER_CONTEXT * rContext, const char *readerName,
-	const char *libraryName, int port, DWORD slot)
+	const char *libraryName, int port)
 {
 	LONG parent = -1;	/* reader number of the parent of the clone */
 	DWORD valueLength;
@@ -559,7 +562,7 @@ LONG RFSetReaderName(READER_CONTEXT * rContext, const char *readerName,
 	for (i = 0; i < PCSCLITE_MAX_READERS_CONTEXTS; i++)
 		usedDigits[i] = FALSE;
 
-	if ((0 == slot) && (dwNumReadersContexts != 0))
+	if (dwNumReadersContexts != 0)
 	{
 		for (i = 0; i < PCSCLITE_MAX_READERS_CONTEXTS; i++)
 		{
@@ -645,11 +648,11 @@ LONG RFSetReaderName(READER_CONTEXT * rContext, const char *readerName,
 	}
 
 	snprintf(rContext->readerState->readerName,
-		sizeof(rContext->readerState->readerName), "%s %02X %02lX",
-		readerName, i, slot);
+		sizeof(rContext->readerState->readerName), "%s %02X 00",
+		readerName, i);
 
 	/* Set the slot in 0xDDDDCCCC */
-	rContext->slot = (i << 16) + slot;
+	rContext->slot = i << 16;
 
 	return parent;
 }
@@ -935,7 +938,7 @@ LONG RFInitializeReader(READER_CONTEXT * rContext)
 	rv = RFLoadReader(rContext);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		Log2(PCSC_LOG_ERROR, "RFLoadReader failed: 0x%X", rv);
+		Log2(PCSC_LOG_ERROR, "RFLoadReader failed: 0x%lX", rv);
 		return rv;
 	}
 
@@ -944,7 +947,7 @@ LONG RFInitializeReader(READER_CONTEXT * rContext)
 
 	if (rv != SCARD_S_SUCCESS)
 	{
-		Log2(PCSC_LOG_ERROR, "RFBindFunctions failed: 0x%X", rv);
+		Log2(PCSC_LOG_ERROR, "RFBindFunctions failed: 0x%lX", rv);
 		(void)RFUnloadReader(rContext);
 		return rv;
 	}
@@ -1029,7 +1032,7 @@ again:
 			while (list_iterator_hasnext(l))
 			{
 				currentHandle = list_iterator_next(l);
-				if ((rContext->dwIdentity + randHandle) ==
+				if (((LONG)rContext->dwIdentity + randHandle) ==
 					(currentHandle->hCard))
 				{
 					/* Get a new handle and loop again */
@@ -1116,7 +1119,7 @@ LONG RFAddReaderHandle(READER_CONTEXT * rContext, SCARDHANDLE hCard)
 	}
 end:
 	(void)pthread_mutex_unlock(&rContext->handlesList_lock);
-	return SCARD_S_SUCCESS;
+	return rv;
 }
 
 LONG RFRemoveReaderHandle(READER_CONTEXT * rContext, SCARDHANDLE hCard)
@@ -1129,7 +1132,7 @@ LONG RFRemoveReaderHandle(READER_CONTEXT * rContext, SCARDHANDLE hCard)
 	currentHandle = list_seek(&(rContext->handlesList), &hCard);
 	if (NULL == currentHandle)
 	{
-		Log2(PCSC_LOG_CRITICAL, "list_seek failed to locate hCard=%X", hCard);
+		Log2(PCSC_LOG_CRITICAL, "list_seek failed to locate hCard=%lX", hCard);
 		rv = SCARD_E_INVALID_HANDLE;
 		goto end;
 	}
@@ -1162,7 +1165,7 @@ LONG RFSetReaderEventState(READER_CONTEXT * rContext, DWORD dwEvent)
 		currentHandle = list_get_at(&(rContext->handlesList), list_index);
 		if (NULL == currentHandle)
 		{
-			Log2(PCSC_LOG_CRITICAL, "list_get_at failed at index %s",
+			Log2(PCSC_LOG_CRITICAL, "list_get_at failed at index %d",
 				list_index);
 			continue;
 		}
@@ -1192,7 +1195,7 @@ LONG RFCheckReaderEventState(READER_CONTEXT * rContext, SCARDHANDLE hCard)
 	if (NULL == currentHandle)
 	{
 		/* Not Found */
-		Log2(PCSC_LOG_CRITICAL, "list_seek failed for hCard 0x%X", hCard);
+		Log2(PCSC_LOG_CRITICAL, "list_seek failed for hCard 0x%lX", hCard);
 		return SCARD_E_INVALID_HANDLE;
 	}
 
@@ -1268,7 +1271,7 @@ void RFCleanupReaders(void)
 			rv = RFRemoveReader(lpcStripReader, sReadersContexts[i]->port);
 
 			if (rv != SCARD_S_SUCCESS)
-				Log2(PCSC_LOG_ERROR, "RFRemoveReader error: 0x%08X", rv);
+				Log2(PCSC_LOG_ERROR, "RFRemoveReader error: 0x%08lX", rv);
 		}
 	}
 }
